@@ -2,7 +2,7 @@
 
 /*
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
- *   Copyright (c) 2013-2016 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
+ *   Copyright (c) 2013-2017 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
  *   The Tcpreplay Suite of tools is free software: you can redistribute it 
  *   and/or modify it under the terms of the GNU General Public License as 
@@ -40,19 +40,22 @@ parse_services(const char *file, tcpr_services_t *services)
     uint16_t portc;
     size_t nmatch = 3;
     regmatch_t pmatch[3];
-    char regex[] = "([0-9]+)/(tcp|udp)"; /* matches the port as pmatch[1], service pmatch[2] */
+    static const char regex[] = "([0-9]+)/(tcp|udp)"; /* matches the port as pmatch[1], service pmatch[2] */
+
+    assert(file);
+    assert(services);
 
     dbgx(1, "Parsing %s", file);
     memset(service_line, '\0', MAXLINE);
 
     /* mark all ports not a service */
-    memset(services->tcp, '\0', NUM_PORTS);
-    memset(services->udp, '\0', NUM_PORTS);
+    memset(&services->tcp[0], '\0', sizeof(services->tcp));
+    memset(&services->udp[0], '\0', sizeof(services->udp));
 
     if ((service = fopen(file, "r")) == NULL) {
         errx(-1, "Unable to open service file: %s\n%s", file, strerror(errno));
     }
-    
+
     /* compile our regexes */
     if ((regcomp(&preg, regex, REG_ICASE|REG_EXTENDED)) != 0) {
         errx(-1, "Unable to compile regex: %s", regex);
@@ -64,9 +67,9 @@ parse_services(const char *file, tcpr_services_t *services)
         memset(port, '\0', 10);
         memset(proto, '\0', 10);
         portc = 0;
-        
-        dbgx(4, "Procesing: %s", service_line);
-        
+
+        dbgx(4, "Processing: %s", service_line);
+
         /* look for format of 1234/tcp */
         if ((regexec(&preg, service_line, nmatch, pmatch, 0)) == 0) { /* matches */
             if (nmatch < 2) {
@@ -92,4 +95,6 @@ parse_services(const char *file, tcpr_services_t *services)
             }
         }
     }
+
+    fclose(service);
 }
